@@ -62,13 +62,13 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
         if uploaded_entry:
             logger.info(f'File with hash {md5_hash} is already uploaded to dataset {dataset_name}.')
             upload_entry = {
-                'bucket': settings.BUCKET,
+                'bucket': credentials.BUCKET,
                 'dataset_name': dataset_name,
                 'file_name': f'{relative_file_path}/{file_name}',
-                'object_name': object_name,
+                'object_name': uploaded_entry['object_name'],
                 'md5_hash': md5_hash,
                 'url': uploaded_entry['URL'],
-                'cdn_url': settings.CDN_URL.format(object_name=object_name),
+                'cdn_url': settings.CDN_URL.format(object_name=uploaded_entry['object_name']),
             }
             return upload_entry
 
